package com.ruoyi.bst.taskSubmit.service.impl;

import java.util.Collections;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.taskSubmit.domain.TaskSubmit;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitQuery;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.bst.taskSubmit.mapper.TaskSubmitMapper;
import com.ruoyi.bst.taskSubmit.service.TaskSubmitService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 任务提交记录Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-08
 */
@Service
public class TaskSubmitServiceImpl implements TaskSubmitService
{
    @Autowired
    private TaskSubmitMapper taskSubmitMapper;

    /**
     * 查询任务提交记录
     *
     * @param id 任务提交记录主键
     * @return 任务提交记录
     */
    @Override
    public TaskSubmitVO selectTaskSubmitById(Long id)
    {
        return taskSubmitMapper.selectTaskSubmitById(id);
    }

    /**
     * 查询任务提交记录列表
     *
     * @param taskSubmit 任务提交记录
     * @return 任务提交记录
     */
    @Override
    public List<TaskSubmitVO> selectTaskSubmitList(TaskSubmitQuery taskSubmit)
    {
        return taskSubmitMapper.selectTaskSubmitList(taskSubmit);
    }

    /**
     * 新增任务提交记录
     *
     * @param taskSubmit 任务提交记录
     * @return 结果
     */
    @Override
    public int insertTaskSubmit(TaskSubmit taskSubmit)
    {
        taskSubmit.setCreateTime(DateUtils.getNowDate());
        return taskSubmitMapper.insertTaskSubmit(taskSubmit);
    }

    /**
     * 修改任务提交记录
     *
     * @param taskSubmit 任务提交记录
     * @return 结果
     */
    @Override
    public int updateTaskSubmit(TaskSubmit taskSubmit)
    {
        return taskSubmitMapper.updateTaskSubmit(taskSubmit);
    }

    /**
     * 批量删除任务提交记录
     *
     * @param ids 需要删除的任务提交记录主键
     * @return 结果
     */
    @Override
    public int deleteTaskSubmitByIds(Long[] ids)
    {
        return taskSubmitMapper.deleteTaskSubmitByIds(ids);
    }

    /**
     * 删除任务提交记录信息
     *
     * @param id 任务提交记录主键
     * @return 结果
     */
    @Override
    public int deleteTaskSubmitById(Long id)
    {
        return taskSubmitMapper.deleteTaskSubmitById(id);
    }

    @Override
    public List<TaskSubmitVO> selectListByTaskIds(List<Long> taskIds) {
        if (CollectionUtils.isEmptyElement(taskIds)) {
            return Collections.emptyList();
        }

        TaskSubmitQuery query = new TaskSubmitQuery();
        query.setTaskIds(taskIds);
        return this.selectTaskSubmitList(query);
    }
}
